@@ -39,6 +39,7 @@ class Config:
 	def __init__(self):
 		self.user = ""
 		self.password = ""
+		self.color = ""
 		self.lastfm_user = ""
 		self.lastfm_password = ""
 		self.lastfm_scrobble_percent = "50"
@@ -73,6 +74,18 @@ class Config:
 		self.event_command = ""
 		
 	def load(self):
+		if os.path.exists('/etc/hildon/theme/colors.config'):
+			f = open('/etc/hildon/theme/colors.config')
+			for line in f:
+				if re.match("ActiveTextColor\s*=",line):
+					self.color = re.match("ActiveTextColor\s*=(.+)",line).group(1).lstrip().rstrip()
+				
+			if self.color == "":
+				self.color = "rgb(255, 255, 255)"
+
+		else:
+			self.color = "rgb(255, 255, 255)"
+		
 		if os.path.exists(os.path.expanduser("~")+'/.config/pianobar/config'):
 			f = open(os.path.expanduser("~")+'/.config/pianobar/config', 'r')
 			for line in f:
@@ -260,6 +273,14 @@ class MyForm(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.ui.actionDelete, QtCore.SIGNAL('triggered()'), self.deleteStation)
 		QtCore.QObject.connect(self.ui.actionCreate, QtCore.SIGNAL('triggered()'), self.createStation)
 		QtCore.QObject.connect(self.ui.actionSnooze, QtCore.SIGNAL('triggered()'), self.setSnooze)
+		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('pressed()'), self.nextDown)
+		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('released()'), self.nextUp)
+		QtCore.QObject.connect(self.ui.btnSleep, QtCore.SIGNAL('pressed()'), self.sleepDown)
+		QtCore.QObject.connect(self.ui.btnSleep, QtCore.SIGNAL('released()'), self.sleepUp)
+		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('pressed()'), self.hateDown)
+		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('released()'), self.hateUp)
+
+
 		QtCore.QObject.connect(self.ui.listStations, QtCore.SIGNAL('activated(int)'), self.setStation)
 		QtCore.QObject.connect(self, QtCore.SIGNAL('triggered()'), self.closeEvent)
 
@@ -275,7 +296,7 @@ class MyForm(QtGui.QMainWindow):
 			elif self.p.last == "song":
 				self.p.pandora.stdin.write(self.c.act_stationchange)
 				self.p.pandora.stdin.write("\n")
-				self.ui.btnPlay.setStyleSheet("background-color: #FFFFFF;\nbackground-image: url(:/img/img/paused-trans.png);")
+				self.ui.btnPlay.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/paused-trans.png);")
 				self.p.playing = 0
 
 			self.p.pandora.stdin.write(self.c.act_stationcreate)
@@ -296,7 +317,7 @@ class MyForm(QtGui.QMainWindow):
 		if reply == QtGui.QMessageBox.Yes:
 			if self.p.last == "song":
 				self.p.pandora.stdin.write(self.c.act_stationchange)
-				self.ui.btnPlay.setStyleSheet("background-color: #FFFFFF;\nbackground-image: url(:/img/img/paused-trans.png);")
+				self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/paused-trans.png);")
 				self.p.playing = 0
 			self.p.pandora.stdin.write(str(self.ui.listStations.currentIndex())+"\n")
 			self.p.pandora.stdin.write(self.c.act_stationdelete)
@@ -322,7 +343,7 @@ class MyForm(QtGui.QMainWindow):
 		
 			self.station = self.ui.listStations.currentIndex()
 			self.p.pandora.stdin.write(str(self.ui.listStations.currentIndex())+"\n")
-			self.ui.btnPlay.setStyleSheet("background-color: #FFFFFF;\nbackground-image: url(:/img/img/playing-trans.png);")
+			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
 
 	def tiredSong(self):
 		if self.p.last == "song":
@@ -344,15 +365,13 @@ class MyForm(QtGui.QMainWindow):
 		self.a.conf (self.p.sArtist,self.p.sAlbum)
 		self.a.start()
 		if self.p.sLike:
-			self.ui.btnLove.setStyleSheet("background-color: rgb(255, 255, 255);\n"
-			"background-image: url(:/img/img/thumbs-up-trans.png);")
-			self.setLoveDown()
+			self.ui.btnLove.setStyleSheet("background-color: "+ self.c.color + ";\n"
+			"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Thumbs-up-right-trans.png);")
 		else:
-			self.ui.btnLove.setStyleSheet("background-image: url(:/img/img/thumbs-up-trans.png);\nbackground-color: #000000;")
+			self.ui.btnLove.setStyleSheet("background-image: url(:/img/img/Thumbs-up-right-trans.png);\nborder: rgb(0, 0, 0);\nbackground-color: rgb(0, 0, 0);")
 
 		if not self.p.playing:
-			self.ui.btnPlay.setStyleSheet("background-image: url(:/img/img/playing-trans.png);\nbackground-color: #FFFFFF;")
-			self.setPlayDown()
+			self.ui.btnPlay.setStyleSheet("background-image: url(:/img/img/playing-trans.png);\nborder: rgb(0, 0, 0);\nbackground-color: "+ self.c.color + ";")
 			self.p.playing = 1
 
 	def uAlbum(self):
@@ -362,26 +381,36 @@ class MyForm(QtGui.QMainWindow):
 	def doLove(self):
 		if self.p.last == "song":
 	 		self.p.pandora.stdin.write(self.c.act_songlove)
-			self.ui.btnLove.setStyleSheet("background-color: rgb(255, 255, 255);\n"
-			"background-image: url(:/img/img/thumbs-up-trans.png);")
+			self.ui.btnLove.setStyleSheet("background-color: "+ self.c.color +";\n"
+			"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Thumbs-up-right-trans.png);")
 			self.ui.btnNext.setFocus()
-			self.setLoveDown()
-			self.setPlayDown()
 	
-	def setLoveDown(self):
-		self.ui.btnLove.setDown ( 1 )
-		
 	def doHate(self):
 		if self.p.last == "song":
 			self.p.pandora.stdin.write(self.c.act_songban)
 
+	def nextDown(self):
+		self.ui.btnNext.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/skip-trans.png);")
+
+	def nextUp(self):
+		self.ui.btnNext.setStyleSheet("background-color: rgb(0, 0, 0);\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/skip-trans.png);")
+
+	def sleepDown(self):
+		self.ui.btnSleep.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/minus-trans.png);")
+
+	def sleepUp(self):
+		self.ui.btnSleep.setStyleSheet("background-color: rgb(0, 0, 0);\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/minus-trans.png);")
+
+	def hateDown(self):
+		self.ui.btnHate.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/thumbs-down-trans.png);")
+
+	def hateUp(self):
+		self.ui.btnHate.setStyleSheet("background-color: rgb(0, 0, 0);\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/thumbs-down-trans.png);")
+
 	def doNext(self):
 		if self.p.last == "song":
 			self.p.pandora.stdin.write(self.c.act_songnext)
 
-	def setPlayDown(self):
-		self.ui.btnPlay.setDown ( 1 )
-
 	def doPlayPause(self):
 		if self.p.last == "stations":
 			self.p.pandora.stdin.write(str(self.ui.listStations.currentIndex())+"\n")
@@ -389,14 +418,12 @@ class MyForm(QtGui.QMainWindow):
 			self.p.pandora.stdin.write(self.c.act_songpause)
 
 		if self.p.playing:
-			self.ui.btnPlay.setStyleSheet("background-color: #FFFFFF;\nbackground-image: url(:/img/img/paused-trans.png);")
+			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/paused-trans.png);")
 			self.ui.btnNext.setFocus()
-			self.setPlayDown()
 			self.p.playing = 0
 		else:
-			self.ui.btnPlay.setStyleSheet("background-color: #FFFFFF;\nbackground-image: url(:/img/img/playing-trans.png);")
+			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
 			self.ui.btnNext.setFocus()
-			self.setPlayDown()
 			self.p.playing = 1
 	
 	def sQuit(self):
@@ -444,12 +471,12 @@ class MyForm(QtGui.QMainWindow):
 			self.c.write()
 
 	def showUsername(self):
-		username,ok = QtGui.QInputDialog.getText(self,"Username", "Pandora Username:")
+		username,ok = QtGui.QInputDialog.getText(self,"Username", "Pandora Username:", QLineEdit.Normal,self.c.user)
 		if ok:
 			self.c.user = username
 			if self.p.last == "username":
 				self.p.pandora.stdin.write(self.c.user+"\n")
-		else:
+		elif self.p.last == "username":
 			self.p.drun = 0
 			self.p.exit()
 			self.doQuit()
@@ -461,7 +488,7 @@ class MyForm(QtGui.QMainWindow):
 			if self.p.last == "password" and not self.p.pandora.stdin.closed:
 				self.p.pandora.stdin.write(self.c.password+"\n")
 			self.c.write()
-		else:
+		elif self.p.last == "password":
 			self.p.drun = 0
 			self.p.exit()
 			self.doQuit()
